@@ -27,8 +27,7 @@ class charCheck:
             default = ['a','b','c','d','e','f','g','h','i','j','k','l','m','n','o','p','q','r','s','t','u','v','w','x','y','z']
         else:
             default = default.split(' ')
-            
-c1Var = False
+
 class dateCalc():
     def checkDate(dateToCheck):
         if(dateToCheck == ''):
@@ -46,7 +45,9 @@ class dateCalc():
         var = round((daydif+monthdif+yeardif),0)
         return str(int(var)) 
 
+
 class candyTimer():
+    c1Var = False 
     def calculateTime(timeToLast):
         if('h' in timeToLast):
             timeToLast = timeToLast.replace('h', '')
@@ -94,23 +95,23 @@ class candyTimer():
     def setup():
         global runMain
         global calculateTime
+        global c1var
         master = Tk()
         master.title('Candy Counter')
-        def toggleVal(var):
-            var = not var
         def guiGet():
             time = e1.get()
             pieces = e2.get()
-            if(c1Var == False):
+            if(candyTimer.c1Var == False):
                 master.destroy()
-            candyTimer.runMain(str(candyTimer.calculateTime(time)),str(pieces), c1Var)
+            candyTimer.runMain(str(candyTimer.calculateTime(time)),str(pieces), candyTimer.c1Var)
         def guiGetEnter(e):
             time = e1.get()
             pieces = e2.get()
-            if(c1Var == False):
+            if(candyTimer.c1Var == False):
                 master.destroy()
-            candyTimer.runMain(str(candyTimer.calculateTime(time)),str(pieces), c1Var)
-        # def toggleVal():
+            candyTimer.runMain(str(candyTimer.calculateTime(time)),str(pieces), candyTimer.c1Var)
+        def toggleVal():
+            candyTimer.c1Var = not candyTimer.c1Var
         Label(master, text='Time to last:\n45s = 45 seconds, 20m or 20 = 20 minutes 1.5h = 1:30 minutes:').grid(row=0, columnspan=2)
         Label(master, text='Amount of Candy:').grid(row=1, columnspan=2)
         Label(master, text='Disable Windows Pop-Ups?').grid(row=2, column=0)
@@ -118,7 +119,7 @@ class candyTimer():
         e2 = Entry(master)
         b1 = Button(master, text='Enter', command = guiGet)
         b2 = Button(master, text='Exit', command = master.destroy)
-        c1 = Checkbutton(master, command= toggleVal(c1Var))
+        c1 = Checkbutton(master, command= toggleVal)
         e1.grid(row=0, column=2, columnspan=2)
         e2.grid(row=1, column=2, columnspan=2)
         c1.grid(row=2, column=1)
